#[repr(i32)]pub enum StatusCode {
SuccessCompleted = 0,
ObjectNotFound = 1,
PortNameNotSpecified = 2,
UnitNotSpecified = 3,
FamilyNotSpecified = 4,
IpAddrNotSpecified = 5,
ArpAddrNotSpecified = 6,
ArpMacNotSpecified = 7,
InterfaceObjectMismatch = 8,
}junos-19-1 only.Expand description
[brief]: Possible status codes for GET RPC operations [detail]: This enum defines the different status codes that could be returned from the backend service processing the API [default]: SUCCESS_COMPLETED
Variants
SuccessCompleted = 0
[brief]: Operation Completed Succesfully
ObjectNotFound = 1
[brief]: Specified interface object is not found [detail]: This error code is returned when the interface object is not configured
PortNameNotSpecified = 2
[brief]: Port name is not specified for the object [detail]: This error code is returned when the config message does not speicfy the port name.
UnitNotSpecified = 3
[brief]: unit number is not specified for the object [detail]: This error code is returned when the config message does not specify the unit number for the object.
FamilyNotSpecified = 4
[brief]: Family is not specified for the object [detail]: This error code is returned when the config message does not contain the family specified.
IpAddrNotSpecified = 5
[brief]: IP Address is not specified for the object [detail]: This error code is returned when the connfig message does not contain the IP address specified.
ArpAddrNotSpecified = 6
[brief]: ARP/NDP Address is not specified for the object [detail]: This error code is returned when the config message does not contain the ARP/NDP address specified.
ArpMacNotSpecified = 7
[brief]: ARP/NDP MAC Address is not specified for the object [detail]: This error code is returned when the config message does not contain the ARP/NDP MAC address specified.
InterfaceObjectMismatch = 8
[brief]: Interface type specified details sent are not matching. [detail]: This happens when the interface type specified at the message level is different from the actual object information that is sent as part of the message, Eg: Specifying “Interface Unit” at message level and sending an “Interface Address” object in the message.
Implementations
Sourceimpl StatusCode
impl StatusCode
Sourceimpl StatusCode
impl StatusCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.