pub struct InterfaceAddRequest {
pub type: i32,
pub interface_object: Option<InterfaceObject>,
}Available on crate feature
junos-20-4 only.Expand description
[brief]: Message definition for the ADD RPC [detail]: This message defines the request that would be sent for the ADD operation for the configuring the different interface objects.
Fields
type: i32[brief]: Specifies the interface type that is being configured [mandatory]:
interface_object: Option<InterfaceObject>[brief]: Information about the possible interface objects [detail]: That could be sent using this message. Only one of the below objects could be set in a message.The interface object information that is being populated should be of the same type as the InterfaceType specified above.
Implementations
Sourceimpl InterfaceAddRequest
impl InterfaceAddRequest
Sourcepub fn type(&self) -> InterfaceType
pub fn type(&self) -> InterfaceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: InterfaceType)
pub fn set_type(&mut self, value: InterfaceType)
Sets type to the provided enum value.