#[repr(i32)]pub enum StatusCode {
Show 38 variants
SuccessCompleted = 0,
NotOwnerOfObject = 1,
PortNameNotSpecified = 2,
UnitNotSpecified = 3,
FamilyNotSpecified = 4,
IpAddrNotSpecified = 5,
ArpAddrNotSpecified = 6,
ArpMacNotSpecified = 7,
InterfaceObjectMismatch = 8,
TunnelNotSpecified = 9,
TunnelNotSupported = 10,
TunnelEncapNotSupported = 11,
TunnelEncapNotSpecified = 12,
TunnelEncapSourceNotSpecified = 13,
TunnelEncapSrcIpv6AddrNotSupported = 14,
TunnelEncapSrcAddrSubnetMaskNotAllowed = 15,
TunnelEncapDestNotSpecified = 16,
TunnelEncapDestIpv6AddrNotSupported = 17,
TunnelEncapDestAddrSubnetMaskNotAllowed = 18,
TunnelEncapVniNotSpecified = 19,
TunnelEncapTunnelEndpointNotSpecified = 20,
TunnelEncapDestUdpPortNotSpecified = 21,
TunnelEncapTypeNotSupportedOnPlatform = 22,
TunnelEncapSrcDestAddrSame = 23,
OperationFailed = 24,
TunnelEncapDestAddrNotSpecified = 25,
TunnelEncapUdpPortProfileMissing = 26,
TunnelEncapUdpFaimlyNotSupported = 27,
TunnelEncapSrcAddrSubnetNotSupported = 28,
TunnelEncapDestAddrSubnetNotSupported = 29,
TunnelSrcAndIntfAddrSameSubnet = 30,
TunnelDestAndIntfAddrSameSubnet = 31,
TunnelRoutingInstanceNotPresent = 32,
TunnelEncapSrcDestAddrNotUnique = 33,
TunnelEncapSrcDestDiffType = 34,
TunnelEncapSrcAddrFamilyNotSupported = 35,
TunnelEncapDestAddrFamilyNotSupported = 36,
TunnelEncapAddrSubnetNotMatching = 37,
}junos-21-4 only.Expand description
[brief]: Possible status codes for ADD RPC operations [detail]: This enum defines the different status codes that could be returned from the backend service processing the API [default]: SUCCESS_COMPLETED
Variants
SuccessCompleted = 0
[brief]: Operation Completed Succesfully
NotOwnerOfObject = 1
[brief]: Interface is already configured by another client. [detail]: This error code is returned when the interface that is being configured is already configured by another client.
PortNameNotSpecified = 2
[brief]: Port name is not specified for the object [detail]: This error code is returned when the config message does not speicfy the port name.
UnitNotSpecified = 3
[brief]: unit number is not specified for the object [detail]: This error code is returned when the config message does not specify the unit number for the object.
FamilyNotSpecified = 4
[brief]: Family is not specified for the object [detail]: This error code is returned when the config message does not specify the family for the object.
IpAddrNotSpecified = 5
[brief]: IP Address is not specified for the object [detail]: This error code is returned when the config message does not specify the IP address for the object.
ArpAddrNotSpecified = 6
[brief]: ARP/NDP Address is not specified for the object [detail]: This error code is returned when the config message does not specify the ARP/NDP address for the object.
ArpMacNotSpecified = 7
[brief]: ARP/NDP MAC Address is not specified for the object [detail]: This error code is returned when the config message does not specify the ARP/NDP MAC address for the object.
InterfaceObjectMismatch = 8
[brief]: Interface type specified details sent are not matching. [detail]: This happens when the interface type specified at the message level is different from the actual object information that is sent as part of the message, Eg: Specifying “Interface Unit” at message level and sending an “Interface Address” object in the message.
TunnelNotSpecified = 9
[brief]: Tunnel config not specified. [detail]: For tunnel interfaces like FTI, tunnel object should be specified. This error is thrown when tunnel is not configured for tunnel interfaces.
TunnelNotSupported = 10
[brief]: Tunnel object is not supported. [detail]: Tunnel object is only suported for FT interfaces as of now. May be supported for other tunnel interfaces in the future.
TunnelEncapNotSupported = 11
[brief]: Encapsulation under tunnel is not supported. [detail]: This status is returned when encapsulation under tunnel is configured for unsupported interfaces. It is supported only for FT interfaces.
TunnelEncapNotSpecified = 12
[brief]: Encapsulation under tunnel is not specified. [detail]: For FTI interfaces, encapsulation under tunnel object should be specified. This status is returned when encapsulation under tunnel is missing
TunnelEncapSourceNotSpecified = 13
[brief]: Source under tunnel encapsulation is not specified. [detail]:
TunnelEncapSrcIpv6AddrNotSupported = 14
[brief]: Source address cannot be IPV6 address. [detail]: Only IPV4 address is allowed as source address.
TunnelEncapSrcAddrSubnetMaskNotAllowed = 15
[brief]: Prefix length is not supported for source address. [detail]: Only host IPV4 address withough prefix length is allowed as source address.
TunnelEncapDestNotSpecified = 16
[brief]: Destination under tunnel encapsulation is not specified.
TunnelEncapDestIpv6AddrNotSupported = 17
[brief]: Destination address cannot be IPV6 address. [detail]: Only IPV4 address is allowed as destination address.
TunnelEncapDestAddrSubnetMaskNotAllowed = 18
[brief]: Prefix length is not supported for destination address. [detail]: Only host IPV4 address withough prefix length is allowed as destination address.
TunnelEncapVniNotSpecified = 19
[brief]: VNI under tunnel encapsulation is not specified. [detail]: Applicable only to vxlan-gpe encapsulation.
TunnelEncapTunnelEndpointNotSpecified = 20
[brief]: tunnel-endpoint under tunnel encapsulation is not specified. [detail]: Applicable only to vxlan-gpe encapsulation.
TunnelEncapDestUdpPortNotSpecified = 21
[brief]: destination-udp-port under tunnel encapsualtion is not specified. [detail]: Applicable only to vxlan-gpe encapsulation.
TunnelEncapTypeNotSupportedOnPlatform = 22
[brief]: Tunnel encapsulation specified is not supported on the current platform. [detail]: For a list of platforms on which each tunnel encapsulation is available, check the documentation of FtiEncapOptions
TunnelEncapSrcDestAddrSame = 23
[brief]: source and destination address are same. [detail]: applicable to fti only. Source and destination address cannot be same.
OperationFailed = 24
[brief]: Operation failed internally. [detail]: In case of unclassifiable errors, this code is returned.
TunnelEncapDestAddrNotSpecified = 25
[brief]: Destination address is needed if tunnel-termination is not configured [detail]: If tunnel-termination option is not configured then destination address is must
TunnelEncapUdpPortProfileMissing = 26
[brief]: port profile is not specified in UDP encapsulation applicable to EVO platform only [detail]: Applicable only to UDP encapsulation
TunnelEncapUdpFaimlyNotSupported = 27
[brief]: wrong family(ISO) specified in UDP encapsulation applicable to EVO platform only [detail]: only inet, inet6, mpls family are allowed for UDP tunnel in decap mode
TunnelEncapSrcAddrSubnetNotSupported = 28
[brief]: Invalid subnet mask specified in src address applicable to EVO platform only [detail]: Only netmask is allowed for IPv4 is /32 and for IPv6 /128 without tunnel termination
TunnelEncapDestAddrSubnetNotSupported = 29
[brief]: Invalid subnet mask specified in dest address applicable to EVO platform only [detail]: Only netmask is allowed for IPv4 is /32 and for IPv6 /128 without tunnel termination
TunnelSrcAndIntfAddrSameSubnet = 30
[brief]: Same interface address and src address under tunnel applicable to EVO platform only [detail]: same interface addr and src addr under tunnel should not belong to same subnet
TunnelDestAndIntfAddrSameSubnet = 31
[brief]: Same interface address and dest address under tunnel applicable to EVO platform only [detail]: same interface addr and dest addr under tunnel should not belong to same subnet
TunnelRoutingInstanceNotPresent = 32
[brief]: Routing Instance doesn’t exist applicable to EVO platform only [detai]: Routing instance name mentioned in the tunnel doesn’t exist
TunnelEncapSrcDestAddrNotUnique = 33
[brief]: Src and Dest pair is not unique applicable to EVO platform only [detail]: Src and Dest pair should be unique under FTI configs
TunnelEncapSrcDestDiffType = 34
[brief]: src and dest address is different type applicable to EVO platform only [detail]: dest address should match the type of source address
TunnelEncapSrcAddrFamilyNotSupported = 35
[brief]: only IPv4/IPv6 are allowed as source address applicable to EVO platform only
TunnelEncapDestAddrFamilyNotSupported = 36
[brief]: only IPv4/IPv6 are allowed as destination address applicable to EVO platform only
TunnelEncapAddrSubnetNotMatching = 37
[brief]: Subnet not matching with existing tunnel IFL address subnet applicable to EVO platform only [detail]: current Subnet of configured address is not matching with subnet address of already configured under tunnel IFL
Implementations
Sourceimpl StatusCode
impl StatusCode
Sourceimpl StatusCode
impl StatusCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.