pub struct InterfaceUnit {
pub number: u32,
}Available on crate feature
junos-22-2 only.Expand description
[brief]: Message definition for the interface unit information. [detail]: This defintion would be used to define the interface unit number for the interface objects. This is needed since the interface unit number could be 0 and when value 0 is set for the unit number, the information is not marked as configured by user.
Fields
number: u32[brief]: Interface unit number [mandatory]: