pub struct StringAttribute {
pub key: String,
pub value: String,
}Available on crate feature
junos-22-4 only.Expand description
[brief]: Message definition for String attribute [detail]: This message defines the format for passing a string attribute for the different interface objects.
Fields
key: String[brief]: Key for the string attribute [detail]: This field specifies the key value for the string attribute.
value: String[brief]: Value for the attribute [detail]: This field specifies the string value for the string attribute.