pub struct InterfaceAddressConfig {
pub port_name: String,
pub unit: Option<InterfaceUnit>,
pub family: i32,
pub ip_address: Option<IpAddress>,
pub attributes: Option<InterfaceAttributeList>,
pub destination_udp_port: u32,
}junos-22-4 only.Expand description
[brief]: Message definition for the interface address object. [detail]: This defintion would be used to send the interface address configuration information using the API.
Fields
port_name: String[brief]: Port name of the Interface [mandatory]:
unit: Option<InterfaceUnit>[brief]: Interface unit number [mandatory]:
family: i32[brief]: Protocol family to be configured for the interface [mandatory]:
ip_address: Option<IpAddress>[brief]: IP address to be configured. [detail]: IP address to be configured for the interface IP address can be IPV4 or IPV6 based on the family specified [mandatory]:
attributes: Option<InterfaceAttributeList>[brief]: List of optional attributes that can be configured [detail]: For top level interface object the attributes that can be configured are as below String Attributes: mac - MAC address that should be configured on the address object.
Integer Attributes
destination_udp_port: u32[brief]: destination-udp-port for FTI udp encapsulation. [detail]: This option is applicable only for FTI udp encapsulation. It will be ignored for all other encapsulations as well as for non FTI.
Implementations